package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.ZySlideshow;
import com.ruoyi.system.service.IZySlideshowService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 轮播图管理Controller
 * 
 * @author libao
 * @date 2024-05-24
 */
@RestController
@RequestMapping("/system/slideshow")
public class ZySlideshowController extends BaseController
{
    @Autowired
    private IZySlideshowService zySlideshowService;

    /**
     * 查询轮播图管理列表
     */
    @PreAuthorize("@ss.hasPermi('system:slideshow:list')")
    @GetMapping("/list")
    public TableDataInfo list(ZySlideshow zySlideshow)
    {
        startPage();
        List<ZySlideshow> list = zySlideshowService.selectZySlideshowList(zySlideshow);
        return getDataTable(list);
    }

    /**
     * 导出轮播图管理列表
     */
    @PreAuthorize("@ss.hasPermi('system:slideshow:export')")
    @Log(title = "轮播图管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ZySlideshow zySlideshow)
    {
        List<ZySlideshow> list = zySlideshowService.selectZySlideshowList(zySlideshow);
        ExcelUtil<ZySlideshow> util = new ExcelUtil<ZySlideshow>(ZySlideshow.class);
        util.exportExcel(response, list, "轮播图管理数据");
    }

    /**
     * 获取轮播图管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:slideshow:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(zySlideshowService.selectZySlideshowById(id));
    }

    /**
     * 新增轮播图管理
     */
    @PreAuthorize("@ss.hasPermi('system:slideshow:add')")
    @Log(title = "轮播图管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ZySlideshow zySlideshow)
    {
        return toAjax(zySlideshowService.insertZySlideshow(zySlideshow));
    }

    /**
     * 修改轮播图管理
     */
    @PreAuthorize("@ss.hasPermi('system:slideshow:edit')")
    @Log(title = "轮播图管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ZySlideshow zySlideshow)
    {
        return toAjax(zySlideshowService.updateZySlideshow(zySlideshow));
    }

    /**
     * 删除轮播图管理
     */
    @PreAuthorize("@ss.hasPermi('system:slideshow:remove')")
    @Log(title = "轮播图管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(zySlideshowService.deleteZySlideshowByIds(ids));
    }
}
